summaryrefslogtreecommitdiffstats
path: root/kdeui/kactivelabel.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:46:43 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:46:43 +0000
commitffe8a83e053396df448e9413828527613ca3bd46 (patch)
treea73d4169e02df4a50f9a12cb165fcd0ab5bac7c6 /kdeui/kactivelabel.h
parent682bf3bfdcbcbb1fca85e8a36ed03e062e0555d5 (diff)
downloadtdelibs-ffe8a83e053396df448e9413828527613ca3bd46.tar.gz
tdelibs-ffe8a83e053396df448e9413828527613ca3bd46.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1157647 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdeui/kactivelabel.h')
-rw-r--r--kdeui/kactivelabel.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/kdeui/kactivelabel.h b/kdeui/kactivelabel.h
index ad5dd12b5..8ab2bacf2 100644
--- a/kdeui/kactivelabel.h
+++ b/kdeui/kactivelabel.h
@@ -19,7 +19,7 @@
#ifndef _KACTIVELABEL_H_
#define _KACTIVELABEL_H_
-#include <qtextbrowser.h>
+#include <tqtextbrowser.h>
#include <kdelibs_export.h>
@@ -41,23 +41,23 @@ public:
/**
* Constructor.
*
* It connects the "linkClicked(const QString &)" signal to the
* "openLink(const QString &)" slot. You will need to disconnect
* this if you want to process linkClicked() yourself.
*/
- KActiveLabel(QWidget * parent, const char * name = 0);
+ KActiveLabel(TQWidget * parent, const char * name = 0);
/**
* Constructor.
*
* It connects the "linkClicked(const QString &)" signal to the
* "openLink(const QString &)" slot. You will need to disconnect
* this if you want to process linkClicked() yourself.
*/
- KActiveLabel(const QString & text, QWidget * parent, const char * name = 0);
+ KActiveLabel(const TQString & text, TQWidget * parent, const char * name = 0);
- QSize minimumSizeHint() const;
- QSize sizeHint() const;
+ TQSize minimumSizeHint() const;
+ TQSize sizeHint() const;
public slots:
/**
@@ -67,19 +67,19 @@ public slots:
* box will appear and then display the rest of the text. The WhatsThis
* functionality is available since KDE 3.2.
*/
- virtual void openLink(const QString & link);
+ virtual void openLink(const TQString & link);
private slots:
void paletteChanged();
- void setSource( const QString &) { }
+ void setSource( const TQString &) { }
private:
void init();
protected:
virtual void virtual_hook( int id, void* data );
- virtual void focusInEvent( QFocusEvent* fe );
- virtual void focusOutEvent( QFocusEvent* fe );
- virtual void keyPressEvent ( QKeyEvent * e );
+ virtual void focusInEvent( TQFocusEvent* fe );
+ virtual void focusOutEvent( TQFocusEvent* fe );
+ virtual void keyPressEvent ( TQKeyEvent * e );
private:
KActiveLabelPrivate *d;
};
@@ -41,23 +41,23 @@ public:
* Constructor.
*
- * It connects the "linkClicked(const QString &)" signal to the
- * "openLink(const QString &)" slot. You will need to disconnect
+ * It connects the "linkClicked(const TQString &)" signal to the
+ * "openLink(const TQString &)" slot. You will need to disconnect
* this if you want to process linkClicked() yourself.
*/
@@ -41,23 +41,23 @@ public:
* Constructor.
*
- * It connects the "linkClicked(const QString &)" signal to the
- * "openLink(const QString &)" slot. You will need to disconnect
+ * It connects the "linkClicked(const TQString &)" signal to the
+ * "openLink(const TQString &)" slot. You will need to disconnect
* this if you want to process linkClicked() yourself.
*/